about summary refs log tree commit diff
path: root/src/librustc_codegen_llvm/debuginfo/utils.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/librustc_codegen_llvm/debuginfo/utils.rs')
-rw-r--r--src/librustc_codegen_llvm/debuginfo/utils.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/librustc_codegen_llvm/debuginfo/utils.rs b/src/librustc_codegen_llvm/debuginfo/utils.rs
index e77dab998d2..53497e396cd 100644
--- a/src/librustc_codegen_llvm/debuginfo/utils.rs
+++ b/src/librustc_codegen_llvm/debuginfo/utils.rs
@@ -11,7 +11,7 @@ use crate::llvm;
 use crate::llvm::debuginfo::{DIArray, DIBuilder, DIDescriptor, DIScope};
 use rustc_codegen_ssa::traits::*;
 
-use syntax_pos::Span;
+use rustc_span::Span;
 
 pub fn is_node_local_to_unit(cx: &CodegenCx<'_, '_>, def_id: DefId) -> bool {
     // The is_local_to_unit flag indicates whether a function is local to the
@@ -32,8 +32,8 @@ pub fn create_DIArray(builder: &DIBuilder<'ll>, arr: &[Option<&'ll DIDescriptor>
     };
 }
 
-/// Returns syntax_pos::Loc corresponding to the beginning of the span
-pub fn span_start(cx: &CodegenCx<'_, '_>, span: Span) -> syntax_pos::Loc {
+/// Returns rustc_span::Loc corresponding to the beginning of the span
+pub fn span_start(cx: &CodegenCx<'_, '_>, span: Span) -> rustc_span::Loc {
     cx.sess().source_map().lookup_char_pos(span.lo())
 }